@@ -26,17 +26,24 @@ import gi
 from datetime import datetime, timedelta
 from typing import Optional
 
-gi.require_version('Gtk', '3.0')  # isort:skip
+gi.require_version("Gtk", "3.0")  # isort:skip
 from gi.repository import Gtk  # isort:skip
 
 from qubes_config.widgets.gtk_utils import load_icon
 from qubesadmin import exc
 
 from qui.utils import check_support
-from qui.updater.utils import disable_checkboxes, HeaderCheckbox, \
-    pass_through_event_window, \
-    QubeName, label_color_theme, UpdateStatus, RowWrapper, \
-    ListWrapper, on_head_checkbox_toggled
+from qui.updater.utils import (
+    disable_checkboxes,
+    HeaderCheckbox,
+    pass_through_event_window,
+    QubeName,
+    label_color_theme,
+    UpdateStatus,
+    RowWrapper,
+    ListWrapper,
+    on_head_checkbox_toggled,
+)
 
 
 class IntroPage:
@@ -56,17 +63,19 @@ class IntroPage:
         self.page: Gtk.Box = self.builder.get_object("list_page")
         self.stack: Gtk.Stack = self.builder.get_object("main_stack")
         self.vm_list: Gtk.TreeView = self.builder.get_object("vm_list")
+        self.vm_list.set_has_tooltip(True)
+        self.vm_list.connect("query-tooltip", self.on_query_tooltip)
         self.list_store: Optional[ListWrapper] = None
 
-        checkbox_column: Gtk.TreeViewColumn = self.builder.get_object(
-            "checkbox_column")
+        checkbox_column: Gtk.TreeViewColumn = self.builder.get_object("checkbox_column")
         checkbox_column.connect("clicked", self.on_header_toggled)
         header_button = checkbox_column.get_button()
 
-        header_button.connect('realize', pass_through_event_window)
+        header_button.connect("realize", pass_through_event_window)
 
         self.checkbox_column_button: Gtk.CheckButton = self.builder.get_object(
-            "checkbox_header")
+            "checkbox_header"
+        )
         self.checkbox_column_button.set_inconsistent(True)
         self.checkbox_column_button.connect("toggled", self.on_header_toggled)
         self.head_checkbox = UpdateHeaderCheckbox(
@@ -75,32 +84,58 @@ class IntroPage:
 
         self.vm_list.connect("row-activated", self.on_checkbox_toggled)
 
-        self.info_how_it_works: Gtk.Label = self.builder.get_object(
-            "info_how_it_works")
+        self.info_how_it_works: Gtk.Label = self.builder.get_object("info_how_it_works")
         self.info_how_it_works.set_label(
             self.info_how_it_works.get_label().format(
                 MAYBE=f'<span foreground="{label_color_theme("orange")}">'
-                      '<b>MAYBE</b></span>',
+                "<b>MAYBE</b></span>",
                 OBSOLETE=f'<span foreground="{label_color_theme("red")}">'
-                      '<b>OBSOLETE</b></span>'
-            ))
+                "<b>OBSOLETE</b></span>",
+                PROHIBITED=f'<span foreground="{label_color_theme("red")}">'
+                "<b>START PROHIBITED</b></span>",
+            )
+        )
 
     def populate_vm_list(self, qapp, settings):
         """Adds to list any updatable vms with update info."""
         self.log.debug("Populate update list")
-        self.list_store = ListWrapper(
-            UpdateRowWrapper, self.vm_list.get_model())
+        self.list_store = ListWrapper(UpdateRowWrapper, self.vm_list.get_model())
 
         for vm in qapp.domains:
-            if vm.klass == 'AdminVM':
+            if vm.klass == "AdminVM":
                 try:
-                    state = bool(vm.features.get('updates-available', False))
+                    if settings.hide_skipped and bool(
+                        vm.features.get("skip-update", False)
+                    ):
+                        continue
+                    state = bool(vm.features.get("updates-available", False))
                 except exc.QubesDaemonCommunicationError:
                     state = False
                 self.list_store.append_vm(vm, state)
 
+        to_update = set()
+        if settings.hide_updated:
+            cmd = [
+                "qubes-vm-update",
+                "--quiet",
+                "--dry-run",
+                "--update-if-stale",
+                str(settings.update_if_stale),
+            ]
+            to_update = self._get_stale_qubes(cmd)
+
         for vm in qapp.domains:
-            if getattr(vm, 'updateable', False) and vm.klass != 'AdminVM':
+            try:
+                if settings.hide_skipped and bool(
+                    vm.features.get("skip-update", False)
+                ):
+                    continue
+                if settings.hide_updated and not vm.name in to_update:
+                    # TODO: Make re-filtering possible without App restart
+                    continue
+            except exc.QubesDaemonCommunicationError:
+                continue
+            if getattr(vm, "updateable", False) and vm.klass != "AdminVM":
                 self.list_store.append_vm(vm)
 
         self.refresh_update_list(settings.update_if_stale)
@@ -113,16 +148,23 @@ class IntroPage:
         if not self.active:
             return
 
-        cmd = ['qubes-vm-update', '--quiet', '--dry-run',
-               '--update-if-stale', str(update_if_stale)]
+        cmd = [
+            "qubes-vm-update",
+            "--quiet",
+            "--dry-run",
+            "--update-if-stale",
+            str(update_if_stale),
+        ]
 
         to_update = self._get_stale_qubes(cmd)
 
         for row in self.list_store:
-            if row.vm.name == 'dom0':
+            if row.vm.name == "dom0":
                 continue
             row.updates_available = bool(row.vm.name in to_update)
-            row.selected = bool(row.vm.name in to_update)
+            row.selected = bool(row.vm.name in to_update) and not row.vm.features.get(
+                "prohibit-start", False
+            )
 
     def get_vms_to_update(self) -> ListWrapper:
         """Returns list of vms selected to be updated"""
@@ -167,23 +209,28 @@ class IntroPage:
         If the user has selected any vms that do not match the defined states,
         the cycle will start from (1).
         """
-        on_head_checkbox_toggled(
-            self.list_store, self.head_checkbox, self.select_rows)
+        on_head_checkbox_toggled(self.list_store, self.head_checkbox, self.select_rows)
 
     def select_rows(self):
         for row in self.list_store:
-            row.selected = row.updates_available \
-                           in self.head_checkbox.allowed
+            row.selected = row.updates_available in self.head_checkbox.allowed
 
     def select_rows_ignoring_conditions(self, cliargs, dom0):
-        cmd = ['qubes-vm-update', '--dry-run', '--quiet']
+        cmd = ["qubes-vm-update", "--dry-run", "--quiet"]
 
         args = [a for a in dir(cliargs) if not a.startswith("_")]
         for arg in args:
-            if arg in ("non_interactive", "non_default_select",
-                       "dom0",
-                       "restart", "apply_to_sys", "apply_to_all", "no_apply",
-                       "max_concurrency", "log"):
+            if arg in (
+                "non_interactive",
+                "non_default_select",
+                "dom0",
+                "restart",
+                "apply_to_sys",
+                "apply_to_all",
+                "no_apply",
+                "max_concurrency",
+                "log",
+            ):
                 continue
             value = getattr(cliargs, arg)
             if value:
@@ -199,7 +246,8 @@ class IntroPage:
 
         to_update = set()
         non_default_select = [
-            '--' + arg for arg in cliargs.non_default_select if arg != 'dom0']
+            "--" + arg for arg in cliargs.non_default_select if arg != "dom0"
+        ]
         non_default = [a for a in cmd if a in non_default_select]
         if non_default or cliargs.non_interactive:
             to_update = self._get_stale_qubes(cmd)
@@ -220,8 +268,8 @@ class IntroPage:
                 return set()
 
             return {
-                vm_name.strip() for vm_name
-                in output_lines[0].split(":", maxsplit=1)[1].split(",")
+                vm_name.strip()
+                for vm_name in output_lines[0].split(":", maxsplit=1)[1].split(",")
             }
         except subprocess.CalledProcessError as err:
             if err.returncode != 100:
@@ -231,18 +279,20 @@ class IntroPage:
     @staticmethod
     def _handle_cli_dom0(dom0, to_update, cliargs):
         default_select = not any(
-            (getattr(cliargs, arg)
-             for arg in cliargs.non_default_select if arg != 'all'))
-        if ((
-            default_select and cliargs.non_interactive
-            or cliargs.all
-            or cliargs.dom0
+            (
+                getattr(cliargs, arg)
+                for arg in cliargs.non_default_select
+                if arg != "all"
+            )
+        )
+        if (
+            default_select and cliargs.non_interactive or cliargs.all or cliargs.dom0
         ) and (
             cliargs.force_update
-            or bool(dom0.features.get('updates-available', False))
+            or bool(dom0.features.get("updates-available", False))
             or is_stale(dom0, cliargs.update_if_stale)
-        )):
-            to_update.add('dom0')
+        ):
+            to_update.add("dom0")
 
         if cliargs.targets and "dom0" in cliargs.targets.split(","):
             to_update.add("dom0")
@@ -250,14 +300,29 @@ class IntroPage:
             to_update = to_update.difference({"dom0"})
         return to_update
 
+    def on_query_tooltip(self, widget, x, y, keyboard_tip, tooltip):
+        """Show appropriate qube tooltip. Currently only for prohibit-start."""
+        if not widget.get_tooltip_context(x, y, keyboard_tip):
+            return False
+        _, x, y, model, path, iterator = widget.get_tooltip_context(x, y, keyboard_tip)
+        if path:
+            status = model[iterator][4]
+            if status == type(status).PROHIBITED:
+                tooltip.set_text(
+                    "Start prohibition rationale:\n{}".format(str(model[iterator][9]))
+                )
+                widget.set_tooltip_cell(tooltip, path, None, None)
+                return True
+        return False
+
 
 def is_stale(vm, expiration_period):
     if expiration_period is None:
         return False
     today = datetime.today()
     last_update_str = vm.features.get(
-        'last-updates-check',
-        datetime.fromtimestamp(0).strftime('%Y-%m-%d %H:%M:%S')
+        "last-updates-check",
+        datetime.fromtimestamp(0).strftime("%Y-%m-%d %H:%M:%S"),
     )
     last_update = datetime.fromisoformat(last_update_str)
     if (today - last_update).days > expiration_period:
@@ -277,27 +342,31 @@ class UpdateRowWrapper(RowWrapper):
     _STATUS = 8
 
     def __init__(self, list_store, vm, to_update: bool):
-        updates_available = bool(vm.features.get('updates-available', False))
+        updates_available = bool(vm.features.get("updates-available", False))
         if to_update and not updates_available:
             updates_available = None
         selected = updates_available is True
         supported = check_support(vm)
 
-        last_updates_check = vm.features.get('last-updates-check', None)
-        last_update = vm.features.get('last-update', None)
+        last_updates_check = vm.features.get("last-updates-check", None)
+        last_update = vm.features.get("last-update", None)
 
         icon = load_icon(vm.icon)
         name = QubeName(vm.name, str(vm.label))
+        prohibit_rationale = vm.features.get("prohibit-start", False)
 
         raw_row = [
             selected,
             icon,
             name,
-            UpdatesAvailable.from_features(updates_available, supported),
+            UpdatesAvailable.from_features(
+                updates_available, supported, bool(prohibit_rationale)
+            ),
             Date(last_updates_check),
             Date(last_update),
             0,
             UpdateStatus.Undefined,
+            prohibit_rationale,
         ]
 
         super().__init__(list_store, vm, raw_row)
@@ -333,14 +402,15 @@ class UpdateRowWrapper(RowWrapper):
 
     @updates_available.setter
     def updates_available(self, value):
-        updates_available = bool(
-            self.vm.features.get('updates-available', False))
+        prohibited = bool(self.vm.features.get("prohibit-start", False))
+        updates_available = bool(self.vm.features.get("updates-available", False))
         supported = check_support(self.vm)
 
         if value and not updates_available:
             updates_available = None
-        self.raw_row[self._UPDATES_AVAILABLE] = \
-            UpdatesAvailable.from_features(updates_available, supported)
+        self.raw_row[self._UPDATES_AVAILABLE] = UpdatesAvailable.from_features(
+            updates_available, supported, prohibited
+        )
 
     @property
     def last_updates_check(self):
@@ -366,10 +436,10 @@ class UpdateRowWrapper(RowWrapper):
 
 class UpdateHeaderCheckbox(HeaderCheckbox):
     def __init__(self, checkbox_column_button, next_button):
-        super().__init__(checkbox_column_button,
-                         [UpdatesAvailable.YES,
-                          UpdatesAvailable.MAYBE,
-                          UpdatesAvailable.NO])
+        super().__init__(
+            checkbox_column_button,
+            [UpdatesAvailable.YES, UpdatesAvailable.MAYBE, UpdatesAvailable.NO],
+        )
         self.next_button = next_button
 
     def all_action(self, *args, **kwargs):
@@ -438,10 +508,16 @@ class UpdatesAvailable(Enum):
     MAYBE = 1
     NO = 2
     EOL = 3
+    PROHIBITED = 4
 
     @staticmethod
-    def from_features(updates_available: Optional[bool],
-                      supported: Optional[str]=None) -> "UpdatesAvailable":
+    def from_features(
+        updates_available: Optional[bool],
+        supported: Optional[str] = None,
+        prohibited: Optional[str] = None,
+    ) -> "UpdatesAvailable":
+        if prohibited:
+            return UpdatesAvailable.PROHIBITED
         if not supported:
             return UpdatesAvailable.EOL
         if updates_available:
@@ -452,6 +528,8 @@ class UpdatesAvailable(Enum):
 
     @property
     def color(self):
+        if self is UpdatesAvailable.PROHIBITED:
+            return label_color_theme("red")
         if self is UpdatesAvailable.YES:
             return label_color_theme("green")
         if self is UpdatesAvailable.MAYBE:
@@ -459,10 +537,12 @@ class UpdatesAvailable(Enum):
         if self is UpdatesAvailable.NO:
             return label_color_theme("black")
         if self is UpdatesAvailable.EOL:
-            return label_color_theme('red')
+            return label_color_theme("red")
 
     def __str__(self):
-        if self is UpdatesAvailable.YES:
+        if self is UpdatesAvailable.PROHIBITED:
+            name = "START PROHIBITED"
+        elif self is UpdatesAvailable.YES:
             name = "YES"
         elif self is UpdatesAvailable.MAYBE:
             name = "MAYBE"
@@ -472,8 +552,7 @@ class UpdatesAvailable(Enum):
             name = "OBSOLETE"
         else:
             name = "ERROR"
-        return f'<span foreground="{self.color}"><b>' \
-               + name + '</b></span>'
+        return f'<span foreground="{self.color}"><b>' + name + "</b></span>"
 
     def __eq__(self, other: "UpdatesAvailable"):
         return self.value == other.value
